==> quarkus-core-deployment-1.0.1.Final-sources.jar: io/quarkus/deployment/steps/ReflectiveHierarchyStep$$accessor.java <==
package io.quarkus.deployment.steps;
public final class ReflectiveHierarchyStep$$accessor {
    private ReflectiveHierarchyStep$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_hierarchy(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).hierarchy;
    }
    @SuppressWarnings("unchecked")
    public static void set_hierarchy(Object __instance, Object hierarchy) {
        ((ReflectiveHierarchyStep)__instance).hierarchy = (java.util.List<io.quarkus.deployment.builditem.nativeimage.ReflectiveHierarchyBuildItem>)hierarchy;
    }
    @SuppressWarnings("unchecked")
    public static Object get_combinedIndexBuildItem(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).combinedIndexBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static void set_combinedIndexBuildItem(Object __instance, Object combinedIndexBuildItem) {
        ((ReflectiveHierarchyStep)__instance).combinedIndexBuildItem = (io.quarkus.deployment.builditem.CombinedIndexBuildItem)combinedIndexBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static Object get_reflectiveClass(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).reflectiveClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_reflectiveClass(Object __instance, Object reflectiveClass) {
        ((ReflectiveHierarchyStep)__instance).reflectiveClass = (io.quarkus.deployment.annotations.BuildProducer<io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem>)reflectiveClass;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ignored(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).ignored;
    }
    @SuppressWarnings("unchecked")
    public static void set_ignored(Object __instance, Object ignored) {
        ((ReflectiveHierarchyStep)__instance).ignored = (java.util.List<io.quarkus.deployment.builditem.nativeimage.ReflectiveHierarchyIgnoreWarningBuildItem>)ignored;
    }
    public static Object construct() {
        return new ReflectiveHierarchyStep();
    }
}

==> quarkus-core-deployment-1.3.1.Final-sources.jar: io/quarkus/deployment/steps/ReflectiveHierarchyStep$$accessor.java <==
package io.quarkus.deployment.steps;
public final class ReflectiveHierarchyStep$$accessor {
    private ReflectiveHierarchyStep$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_hierarchy(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).hierarchy;
    }
    @SuppressWarnings("unchecked")
    public static void set_hierarchy(Object __instance, Object hierarchy) {
        ((ReflectiveHierarchyStep)__instance).hierarchy = (java.util.List<io.quarkus.deployment.builditem.nativeimage.ReflectiveHierarchyBuildItem>)hierarchy;
    }
    @SuppressWarnings("unchecked")
    public static Object get_combinedIndexBuildItem(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).combinedIndexBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static void set_combinedIndexBuildItem(Object __instance, Object combinedIndexBuildItem) {
        ((ReflectiveHierarchyStep)__instance).combinedIndexBuildItem = (io.quarkus.deployment.builditem.CombinedIndexBuildItem)combinedIndexBuildItem;
    }
    @SuppressWarnings("unchecked")
    public static Object get_reflectiveClass(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).reflectiveClass;
    }
    @SuppressWarnings("unchecked")
    public static void set_reflectiveClass(Object __instance, Object reflectiveClass) {
        ((ReflectiveHierarchyStep)__instance).reflectiveClass = (io.quarkus.deployment.annotations.BuildProducer<io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem>)reflectiveClass;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ignored(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).ignored;
    }
    @SuppressWarnings("unchecked")
    public static void set_ignored(Object __instance, Object ignored) {
        ((ReflectiveHierarchyStep)__instance).ignored = (java.util.List<io.quarkus.deployment.builditem.nativeimage.ReflectiveHierarchyIgnoreWarningBuildItem>)ignored;
    }
    @SuppressWarnings("unchecked")
    public static Object get_finalFieldsWritablePredicates(Object __instance) {
        return ((ReflectiveHierarchyStep)__instance).finalFieldsWritablePredicates;
    }
    @SuppressWarnings("unchecked")
    public static void set_finalFieldsWritablePredicates(Object __instance, Object finalFieldsWritablePredicates) {
        ((ReflectiveHierarchyStep)__instance).finalFieldsWritablePredicates = (java.util.List<io.quarkus.deployment.builditem.nativeimage.ReflectiveClassFinalFieldsWritablePredicateBuildItem>)finalFieldsWritablePredicates;
    }
    public static Object construct() {
        return new ReflectiveHierarchyStep();
    }
}
